tlslite.utils.dateFuncs

Package tlslite :: Package utils :: Module dateFuncs |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.dateFuncs

Function Summary
| `createDateClass(year, month, day, hour, minute, second)`
| `getHoursFromNow(hours)`
| `getMinutesFromNow(minutes)`
| `getNow()`
| `isDateClassBefore(d1, d2)`
| `isDateClassExpired(d)`
| `parseDateClass(s)`
| `printDateClass(d)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net